from setuptools import setup, find_packages


setup(
    name="ErfanIO",
    version="0.0.4",
    packages=find_packages(),
    url="https://gitlab.com/Azadeh-Afzar/Utility-Development/ErfanIO",
    license="AGPL-3.0",
    author="Mohammad Mahdi Baghbani Pourvahid",
    author_email="MahdiBaghbani@protonmail.com",
    description="Simple and painless IO library",
    classifiers=[
        "Development Status :: 4 - Beta",
        "Environment :: Console",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: GNU Affero General Public License v3",
        "License :: OSI Approved :: zlib/libpng License",
        "Topic :: Software Development",
        "Topic :: Utilities",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7"
    ]
)
